@@ -1,6 +1,7 @@
 from typing import Iterable, Optional
 
 from crowdin_api.api_resources.abstract.resources import BaseResource
+from crowdin_api.api_resources.distributions.enums import ExportMode
 from crowdin_api.api_resources.distributions.types import DistributionPatchRequest
 
 
@@ -9,7 +10,7 @@ class DistributionsResource(BaseResource):
     Resource for Distributions.
 
     Link to documentation:
-    https://support.crowdin.com/api/v2/#tag/Distributions
+    https://developer.crowdin.com/api/v2/#tag/Distributions
     """
 
     def get_distributions_path(self, projectId: int, hash: Optional[str] = None):
@@ -21,7 +22,6 @@ class DistributionsResource(BaseResource):
     def list_distributions(
         self,
         projectId: int,
-        page: Optional[int] = None,
         offset: Optional[int] = None,
         limit: Optional[int] = None,
     ):
@@ -29,27 +29,43 @@ class DistributionsResource(BaseResource):
         List Distributions.
 
         Link to documentation:
-        https://support.crowdin.com/api/v2/#operation/api.projects.distributions.getMany
+        https://developer.crowdin.com/api/v2/#operation/api.projects.distributions.getMany
         """
 
         return self.requester.request(
             method="get",
             path=self.get_distributions_path(projectId=projectId),
-            params=self.get_page_params(page=page, offset=offset, limit=limit),
+            params=self.get_page_params(offset=offset, limit=limit),
         )
 
-    def add_distribution(self, projectId: int, name: str, fileIds: Iterable[int]):
+    def add_distribution(
+            self,
+            projectId: int,
+            name: str,
+            fileIds: Iterable[int],
+            exportMode: Optional[ExportMode] = ExportMode.DEFAULT,
+            format: Optional[str] = None,
+            exportPattern: Optional[str] = None,
+            labelIds: Optional[Iterable[int]] = None
+    ):
         """
         Add Distribution.
 
         Link to documentation:
-        https://support.crowdin.com/api/v2/#operation/api.projects.distributions.post
+        https://developer.crowdin.com/api/v2/#operation/api.projects.distributions.post
         """
 
         return self.requester.request(
             method="post",
             path=self.get_distributions_path(projectId=projectId),
-            request_data={"name": name, "fileIds": fileIds},
+            request_data={
+                "exportMode": exportMode,
+                "name": name,
+                "fileIds": fileIds,
+                "format": format,
+                "exportPattern": exportPattern,
+                "labelIds": labelIds
+            },
         )
 
     def get_distribution(self, projectId: int, hash: str):
@@ -57,7 +73,7 @@ class DistributionsResource(BaseResource):
         Get Distribution.
 
         Link to documentation:
-        https://support.crowdin.com/api/v2/#operation/api.projects.distributions.get
+        https://developer.crowdin.com/api/v2/#operation/api.projects.distributions.get
         """
 
         return self.requester.request(
@@ -70,7 +86,7 @@ class DistributionsResource(BaseResource):
         Delete Distribution.
 
         Link to documentation:
-        https://support.crowdin.com/api/v2/#operation/api.projects.distributions.delete
+        https://developer.crowdin.com/api/v2/#operation/api.projects.distributions.delete
         """
 
         return self.requester.request(
@@ -85,7 +101,7 @@ class DistributionsResource(BaseResource):
         Edit Distribution.
 
         Link to documentation:
-        https://support.crowdin.com/api/v2/#operation/api.projects.distributions.patch
+        https://developer.crowdin.com/api/v2/#operation/api.projects.distributions.patch
         """
 
         return self.requester.request(
@@ -99,7 +115,7 @@ class DistributionsResource(BaseResource):
         Get Distribution Release.
 
         Link to documentation:
-        https://support.crowdin.com/api/v2/#operation/api.projects.distributions.release.get
+        https://developer.crowdin.com/api/v2/#operation/api.projects.distributions.release.get
         """
 
         return self.requester.request(
@@ -112,7 +128,7 @@ class DistributionsResource(BaseResource):
         Release Distribution.
 
         Link to documentation:
-        https://support.crowdin.com/api/v2/#operation/api.projects.distributions.release.post
+        https://developer.crowdin.com/api/v2/#operation/api.projects.distributions.release.post
         """
 
         return self.requester.request(
