@@ -16,6 +16,8 @@ from crowdin_api.api_resources.reports.types import (
     SimpleIndividualRate,
     SimpleRegularRate,
     StepTypes,
+    ReportSettingsTemplatesPatchRequest,
+    Config,
 )
 
 
@@ -31,7 +33,7 @@ class BaseReportsResource(BaseResource):
         Generate Report.
 
         Link to documentation:
-        https://support.crowdin.com/api/v2/#operation/api.projects.reports.post
+        https://developer.crowdin.com/api/v2/#operation/api.projects.reports.post
 
         Link to documentation for enterprise:
         https://developer.crowdin.com/enterprise/api/v2/#operation/api.reports.download.download
@@ -72,7 +74,7 @@ class BaseReportsResource(BaseResource):
         Generate Report(Top Members).
 
         Link to documentation:
-        https://support.crowdin.com/api/v2/#operation/api.projects.reports.post
+        https://developer.crowdin.com/api/v2/#operation/api.projects.reports.post
 
         Link to documentation for enterprise:
         https://developer.crowdin.com/enterprise/api/v2/#operation/api.projects.reports.post
@@ -105,7 +107,7 @@ class BaseReportsResource(BaseResource):
         Generate Report(Contribution Raw Data).
 
         Link to documentation:
-        https://support.crowdin.com/api/v2/#operation/api.projects.reports.post
+        https://developer.crowdin.com/api/v2/#operation/api.projects.reports.post
 
         Link to documentation for enterprise:
         https://developer.crowdin.com/enterprise/api/v2/#operation/api.projects.reports.post
@@ -131,7 +133,7 @@ class BaseReportsResource(BaseResource):
         Check Report Generation Status.
 
         Link to documentation:
-        https://support.crowdin.com/api/v2/#operation/api.projects.reports.get
+        https://developer.crowdin.com/api/v2/#operation/api.projects.reports.get
 
         Link to documentation for enterprise:
         https://developer.crowdin.com/enterprise/api/v2/#operation/api.projects.reports.get
@@ -147,7 +149,7 @@ class BaseReportsResource(BaseResource):
         Download Report.
 
         Link to documentation:
-        https://support.crowdin.com/api/v2/#operation/api.projects.reports.download.download
+        https://developer.crowdin.com/api/v2/#operation/api.projects.reports.download.download
 
         Link to documentation for enterprise:
         https://developer.crowdin.com/enterprise/api/v2/#operation/api.projects.reports.download.download
@@ -159,7 +161,145 @@ class BaseReportsResource(BaseResource):
         )
 
 
-class ReportsResource(BaseReportsResource):
+class BaseReportSettingsTemplatesResource(BaseResource):
+    def get_report_settings_templates_path(
+        self,
+        projectId: int,
+        reportSettingsTemplateId: Optional[int] = None
+    ):
+        if reportSettingsTemplateId is not None:
+            return f"projects/{projectId}/reports/settings-templates/{reportSettingsTemplateId}"
+
+        return f"projects/{projectId}/reports/settings-templates"
+
+    def list_report_settings_template(
+        self,
+        projectId: int,
+        offset: Optional[int] = None,
+        limit: Optional[int] = None
+    ):
+        """
+        List Report Settings Templates.
+
+        Link to documentation:
+        https://developer.crowdin.com/api/v2/#operation/api.projects.reports.settings-templates.getMany
+
+        Link to documentation for enterprise:
+        https://developer.crowdin.com/enterprise/api/v2/#operation/api.projects.reports.settings-templates.getMany
+        """
+
+        return self.requester.request(
+            method="get",
+            path=self.get_report_settings_templates_path(projectId=projectId),
+            params=self.get_page_params(offset=offset, limit=limit),
+        )
+
+    def add_report_settings_template(
+        self,
+        projectId: int,
+        name: str,
+        currency: Currency,
+        unit: Unit,
+        config: Config,
+    ):
+        """
+        Add Report Settings Templates.
+
+        Link to documentation:
+        https://developer.crowdin.com/api/v2/#operation/api.projects.reports.settings-templates.post
+
+        Link to documentation for enterprise:
+        https://developer.crowdin.com/enterprise/api/v2/#operation/api.projects.reports.settings-templates.post
+        """
+
+        return self.requester.request(
+            method="post",
+            path=self.get_report_settings_templates_path(
+                projectId=projectId,
+            ),
+            request_data={
+                "name": name,
+                "currency": currency,
+                "unit": unit,
+                "mode": "simple",
+                "config": config
+            }
+        )
+
+    def get_report_settings_template(
+        self,
+        projectId: int,
+        reportSettingsTemplateId: int,
+    ):
+        """
+        Get Report Settings Templates.
+
+        Link to documentation:
+        https://developer.crowdin.com/api/v2/#operation/api.projects.reports.settings-templates.get
+
+        Link to documentation for enterprise:
+        https://developer.crowdin.com/enterprise/api/v2/#operation/api.projects.reports.settings-templates.get
+        """
+
+        return self.requester.request(
+            method="get",
+            path=self.get_report_settings_templates_path(
+                projectId=projectId,
+                reportSettingsTemplateId=reportSettingsTemplateId
+            ),
+        )
+
+    def edit_report_settings_template(
+        self,
+        projectId: int,
+        reportSettingsTemplateId: int,
+        data: Iterable[ReportSettingsTemplatesPatchRequest]
+
+    ):
+        """
+        Edit Report Settings Templates.
+
+        Link to documentation:
+        https://developer.crowdin.com/api/v2/#operation/api.projects.reports.settings-templates.patch
+
+        Link to documentation for enterprise:
+        https://developer.crowdin.com/enterprise/api/v2/#operation/api.projects.reports.settings-templates.patch
+        """
+
+        return self.requester.request(
+            method="patch",
+            path=self.get_report_settings_templates_path(
+                projectId=projectId,
+                reportSettingsTemplateId=reportSettingsTemplateId
+            ),
+            request_data=data,
+        )
+
+    def delete_report_settings_template(
+        self,
+        projectId: int,
+        reportSettingsTemplateId: int,
+    ):
+        """
+        Delete Report Settings Templates.
+
+        Link to documentation:
+        https://developer.crowdin.com/api/v2/#operation/api.projects.settings-templates.delete
+
+        Link to documentation for enterprise:
+        https://developer.crowdin.com/enterprise/api/v2/#operation/api.projects.settings-templates.delete
+        """
+
+        return self.requester.request(
+            method="delete",
+            path=self.get_report_settings_templates_path(
+                projectId=projectId,
+                reportSettingsTemplateId=reportSettingsTemplateId
+            ),
+        )
+
+
+class ReportsResource(BaseReportsResource, BaseReportSettingsTemplatesResource):
     """
     Resource for Reports.
 
@@ -170,7 +310,7 @@ class ReportsResource(BaseReportsResource):
     and shall be completed with a sequence of API methods.
 
     Link to documentation:
-    https://support.crowdin.com/api/v2/#tag/Reports
+    https://developer.crowdin.com/api/v2/#tag/Reports
     """
 
     def generate_simple_cost_estimate_report(
@@ -191,7 +331,7 @@ class ReportsResource(BaseReportsResource):
         Generate Report(Cost Estimate Schema).
 
         Link to documentation:
-        https://support.crowdin.com/api/v2/#operation/api.projects.reports.post
+        https://developer.crowdin.com/api/v2/#operation/api.projects.reports.post
         """
 
         return self.generate_report(
@@ -232,7 +372,7 @@ class ReportsResource(BaseReportsResource):
         Generate Report(Cost Estimate Fuzzy Mode).
 
         Link to documentation:
-        https://support.crowdin.com/api/v2/#operation/api.projects.reports.post
+        https://developer.crowdin.com/api/v2/#operation/api.projects.reports.post
         """
 
         return self.generate_report(
@@ -271,7 +411,7 @@ class ReportsResource(BaseReportsResource):
         Generate Report(Translation Cost).
 
         Link to documentation:
-        https://support.crowdin.com/api/v2/#operation/api.projects.reports.post
+        https://developer.crowdin.com/api/v2/#operation/api.projects.reports.post
         """
 
         return self.generate_report(
@@ -308,7 +448,7 @@ class ReportsResource(BaseReportsResource):
         Generate Report(Translation Fuzzy Cost).
 
         Link to documentation:
-        https://support.crowdin.com/api/v2/#operation/api.projects.reports.post
+        https://developer.crowdin.com/api/v2/#operation/api.projects.reports.post
         """
 
         return self.generate_report(
@@ -330,7 +470,7 @@ class ReportsResource(BaseReportsResource):
         )
 
 
-class EnterpriseReportsResource(BaseReportsResource):
+class EnterpriseReportsResource(BaseReportsResource, BaseReportSettingsTemplatesResource):
     """
     Resource for Enterprise Reports.
 
@@ -370,7 +510,7 @@ class EnterpriseReportsResource(BaseReportsResource):
         Generate Report(Cost Estimate schema).
 
         Link to documentation:
-        https://support.crowdin.com/api/v2/#operation/api.projects.reports.post
+        https://developer.crowdin.com/api/v2/#operation/api.projects.reports.post
         """
         step_types_const = {
             "type": "Translate",
